@@ -56,6 +56,7 @@ class ValidationError(PresalyticsBaseException):
 
 class ApiError(PresalyticsBaseException):
     def __init__(self, message=None, status_code=None):
+        self.status_code = status_code
         if not message:
             if not status_code:
                 message = "A error occured while commuicating with the presalytics API.  Please Check your configuration values and try again."
@@ -63,7 +64,11 @@ class ApiError(PresalyticsBaseException):
                 message = "Status Code: {0}".format(status_code)
         else:
             if status_code:
-                message = message + ".  Status Code: {0}".format(status_code)
+                try:
+                    message = message.decode('utf-8')
+                except Exception:
+                    pass
+                message = str(message) + ".  Status Code: {0}".format(status_code)
         super().__init__(message)
 
 
