@@ -2,11 +2,14 @@ import unittest
 import os
 import json
 import lxml
+import base64
+import io
 import presalytics.story.revealer
 import presalytics.story.outline
 import presalytics.lib.tools.component_tools
 import presalytics.lib.widgets.ooxml_editors
 
+
 class TestStory(unittest.TestCase):
     """
     Test module features thatr render stories to dashboards or other formats.
@@ -65,7 +68,7 @@ class TestStory(unittest.TestCase):
 
         revealer = presalytics.story.revealer.Revealer(outline)
 
-        self.assertEqual(len(revealer.plugin_mgr.dependency_map), 8)
+        self.assertGreaterEqual(len(revealer.plugin_mgr.dependency_map), 8)
 
         html_str = revealer.package_as_standalone().decode('utf-8')
 
@@ -98,7 +101,25 @@ class TestStory(unittest.TestCase):
         for _, val in params.items():
             self.assertTrue(val in updates)
 
+    def upload_from_json(self):
+        from presalytics.client.presalytics_story import FileUpload
 
+        test_file = os.path.join(os.path.dirname(__file__), 'files', 'bubblechart.pptx')
+        with open(test_file, 'rb') as f:
+            bin = f.read()
+            content_length = len(bin)
+            data = base64.b64encode(bin).decode('UTF-8')
+            
+        client = presalytics.Client()
+        file = FileUpload(
+            content_length=content_length,
+            file_name="test.pptx",
+            mimetype='application/vnd.openxmlformats-officedocument.presentationml.presentation',
+            file=str(data)
+        )
+        story = client.story.story_post_file_json(file_upload=file)
+        from presalytics.client.presalytics_story import Story
+        self.assertTrue(type(story) is Story)
 
     def tearDown(self):
         pass
